
var AM = AM || {}
AM.Message = {
    /**
     * 弹出框节点
     * @property _el
     * @type Element|Null
     * @default null
     * @private
     */
    _el : null,
    /**
     * 遮盖层节点
     * @property _el_bg
     * @type Element|Null
     * @default null
     * @private
     */
    _el_bg : null,
    /**
     * 弹出框操作后的回调方法集
     * @property _fun
     * @type Objcet
     * @default {}
     * @private
     */
    _fun : {},
    /**
     * 是否点击后自动关闭
     * @property _auto_close
     * @type Boolean
     * @default true
     * @private
     */
    _auto_close : true,
    /**
     * 创建弹出框方法
     * @namespace MT.msg
     * @method _create
     * @private
     */
    _create : function(conf){
        //处理点击操作
        var _this = this;

        //插入遮盖层
        this._el_bg = $('<div class="msg-bg"></div>');
        if (!conf.disableShade) {
            $('body').append(this._el_bg);
        }
        //插入弹出层
        this._el = $('<div id="msg" class="msg-doc"></div>');
        $('body').append(this._el);
        this._el_bg.click(function(){
            if(conf.closeOut) {
                _this.close();
            }
        });

        this._el.on('click', '.msg-close,.msg-btn,.msg-btn-cancel', function(e){
            var event = $(this).attr('data-event');
            if(typeof(_this._fun[event]) == 'function'){
                _this._fun[event]($(this));
                e.preventDefault();
            }
            if(_this._auto_close || event == "cancel"){
                _this.close();
            }
        });
    },
    /**
     * _内部方法，显示对话框并且定位
     * @namespace MT.msg
     * @method _show
     * @param {Object} conf 弹框配置
     * {
         *     content : '', //弹框内容
         *     title : '提示', //弹出框标题
         *     okText : '确定', //Ok按钮的文字
         *     okGE : 'a/b/c', //OK的gaevent值
         *     cancelText : '取消', //Cancel按钮的文字
         *     cancelGE : 'a/b/c', //Cancel的gaevent值
         *     closeRT : true, //是否显示右上角关闭按钮
         *     type : 'alert',//弹框类型
         *     autoClose : false //是否点击按钮后自动关闭
         * }
     * @static
     */
    _show: function (conf) {
        conf = conf || {};
        this.conf = conf;
        //如果之前没有创建，就即时创建
        if(typeof closeTimer != 'undefined')clearTimeout(closeTimer);
        $('.msg-doc').remove();
        $('.msg-bg').remove();
        this._create(conf);

        //自动关闭处理
        this._auto_close = conf.autoClose == undefined ? true : conf.autoClose;

        //组织代码
        if (conf.type == 'alert' || conf.type == 'confirm') {
            //处理ga值
            conf.okGE = conf.okGE || 'msg/ok';
            conf.cancelGE = conf.cancelGE || 'msg/cancel';

            var html = '';
            if (conf.title != undefined) {
                html += '<div class="msg-hd">'
                + conf.title
                + (conf.closeRT === true ? '<a class="msg-close" gaevent="'+ conf.okGE +'" data-event="close" href="#">×</a>' : '')
                + '</div>';
            }
            html += '<div class="msg-bd">' + conf.content + '</div>'
            + '<div class="msg-ft cf">'
            + '<span class="msg-btn msg-btn-ok" gaevent="'+ conf.okGE +'" data-event="ok">'+(!conf.okText ? '确定' : conf.okText)+'</span>'
            + (conf.type == 'confirm' ? '<span class="msg-btn msg-btn-cancel" gaevent="'+ conf.cancelGE +'" data-event="cancel">'+(!conf.cancelText ? '取消' : conf.cancelText)+'</span>': '')
            + '</div>';
        } else if (conf.type == 'dialog') {
            var html = '';
            html += '<div class="msg-hd">'
            + conf.title
            + (conf.closeRT === true ? '<a class="msg-close" gaevent="'+ conf.okGE +'" data-event="close" href="#">×</a>' : '')
            + '</div>';
            if(conf.content){
                html += '<div class="msg-bd">' + conf.content + '</div>'
            }
            html += '<div class="msg-ft cf">'
            + '<span class="msg-btn msg-btn-ok" gaevent="'+ conf.okGE +'" data-event="ok">'+(!conf.okText ? '确定' : conf.okText)+'</span>'
            + '</div>';
        } else if (conf.type == 'buttons_dialog') {
            var html = '';
            if(conf.title){
                html += '<div class="msg-hd">'
                + conf.title
                + (conf.closeRT === true ? '<a class="msg-close" gaevent="'+ conf.okGE +'" data-event="close" href="#">×</a>' : '')
                + '</div>';
            }
            if(conf.desc){
                html += '<div class="msg-desc">' + conf.desc + '</div>'
            }
            var button_html = ''
            var btns = conf['buttons']
            for(var i in btns){
                if(btns[i].text){
                    if(btns[i].fun){
                        this._fun['btn_'+i] = btns[i].fun;
                    }
                    var ge = btns[i].ge || 'msg/btn_'+i;
                    button_html += '<span class="msg-btn msg-btn-ok '+(btns[i].cls ? ' '+btns[i].cls : '')+'" gaevent="'+ ge +'" data-event="btn_'+i+'">'+btns[i].text+'</span>';
                }
            }
            if(conf.content){
                html += '<div class="msg-bd">' + conf.content + '</div>'
            }
            html += '<div class="msg-ft cf">'
            + button_html
            + '</div>';
        } else if(conf.content) {
            var html = conf.content;
        }

        //遮盖部分的计算
        this._el_bg.css('left', '0');
        this._el_bg.css('height', Math.max($(window).height(), $(document).height())+'px');

        //输出内容
        if (html) {
            this._el.html(html);
        } else {
            this._el.append(conf.dom);
        }
        this._el[0].className = 'msg-doc msg-'+ conf.type;

        window.scrollBy(0, 1);
    },
    /**
     * 关闭对话框
     * @namespace MT.msg
     * @method close
     * @static
     */
    close : function () {
        if (this.conf.closeFun) {
            this.conf.closeFun();
        } else {
            var _this = this;
//            _this._el.animate({
//                scale: ".8",
//                opacity: "0"
//            }, 200, "ease-in");
            _this._el.fadeOut(300);
            _this._el_bg.fadeOut(300);
            closeTimer = setTimeout(function(){
                _this._el.remove();
                _this._el_bg.remove();
            }, 0);
        }
    },

    dialog: function (conf) {
        conf = conf || {};
        conf.type = 'dialog';
        conf.closeOut = (conf.closeOut === false)? false : true;
        this.conf = conf;
        this._fun.ok = conf.okFun;
        this._show(conf);
    },

    buttons_dialog: function (title, desc, text, btns, conf) {
        conf = conf || {};
        conf.type = 'buttons_dialog';
        conf.closeOut = (conf.closeOut === false)? false : true;
        conf.content = text;
        conf.title = title
        conf.desc = desc
        conf.buttons = btns
        this._show(conf);
    },

    /**
     * 自定义Alert
     * @namespace MT.msg
     * @method alert
     * @param {String} text 弹出框显示的文本内容
     * @param {Function} [ok_fun] 点击Ok后的处理方法，默认点击后会直接关闭对话框
     * @param {Object} [conf] 弹出框的配置
     *     {
         *         title : '提示', //弹出框标题
         *         okText : '确定', //OK按钮的文字
         *         okGE : 'a/b/c', //OK的gaevent值
         *         closeRT : true, //是否显示右上角关闭按钮
         *         autoClose : false //是否点击按钮后自动关闭
         *     }
     * @static
     */
    alert: function(text, ok_fun, conf){
        conf = conf || {};
        conf.type = 'alert';
        conf.content = text;
        this._fun = ok_fun ? {ok:ok_fun} : {};
        this._show(conf);
    },
    toast: function (text, conf,duration) {
        conf = conf ||{
            duration:duration||2000
        };

        $('.msg-toast').remove();
        var dom = $('<div class="msg-doc msg-toast" style="animation-duration:'+conf.duration+'ms;">' + text + '</div>').appendTo('body');
    },
    /**
     * 自定义Confirm
     * @namespace MT.msg
     * @method confirm
     * @param {String} text 弹出框显示的文本内容
     * @param {Object} [fun] 点击后的处理方法，默认点击后会直接关闭对话框
     *     {
         *         ok : function(){},
         *         cancel : function(){}
         *     }
     * @param {Object} [conf] 弹出框的配置
     *     {cancelT
         *         title : '提示', //弹出框标题
         *         okText : '确定', //Ok按钮的文字
         *         okGE : 'a/b/c', //OK的gaevent值
         *         cancelText : '取消', //Cancel按钮的文字
         *         cancelGE : 'a/b/c', //Cancel的gaevent值
         *         closeRT : true, //是否显示右上角关闭按钮
         *         autoClose : false //是否点击按钮后自动关闭
         *     }
     * @static
     */
    confirm: function (text, fun, conf) {
        conf = conf || {};
        conf.type = 'confirm';
        conf.content = text;
        if (typeof fun == "function") {
            fun = {ok: fun}
        }
        this._fun = fun || {};
        this._show(conf);
    },
    /**
     * ios风格多按钮弹出框
     * @namespace MT.msg
     * @method option
     * @param {String} text 弹出框显示内容
     * @param {Array} [btns] 按钮组的配置
     *     [
     *         {
         *             text : '按钮名称', //按钮的名称
         *             url : '#', //按钮需要跳转的URL
         *             fun : function(){}, //点击按钮需要运行的方法
         *             cls : 'class', //按钮需要使用的特殊样式
         *             ge : 'a/b/c' //按钮的gaevent值
         *         },
     *         ...
     *     ]
     * @param {Function} [cancel_fun] 弹出框的配置
     * @param {Object} [option] 弹出框的配置
     *     {
         *         cancelText : '取消', //Cancel按钮的文字
         *         cancelGE : 'a/b/c', //Cancel的gaevent值
         *         autoClose : false //是否点击按钮后自动关闭
         *     }
     * @static
     */
    option: function (text, btns, cancel_fun, conf) {
        conf = conf || {};
        conf.type = 'option';
        this._fun = cancel_fun ? {cancel:cancel_fun} : {};
        var html = '';
        html += text ? '<div class="msg-bd">'+ text +'</div>' : '';
        html += '<div class="msg-option-btns">';
        for(var i in btns){
            if(btns[i].text){
                if(btns[i].fun){
                    this._fun['btn_'+i] = btns[i].fun;
                }
                var ge = btns[i].ge || 'msg/btn_'+i;
                if(btns[i].url){
                    html += '<a class="btn msg-btn'+(btns[i].cls ? ' '+btns[i].cls : '')+'" gaevent="'+ ge +'" href="'+btns[i].url+'">'+btns[i].text+'</a>';
                }else{
                    html += '<button class="btn msg-btn'+(btns[i].cls ? ' '+btns[i].cls : '')+'" gaevent="'+ ge +'" data-event="btn_'+i+'" type="button">'+btns[i].text+'</button>';
                }
            }
        }
        html += '</div>';
        html += '<button class="btn msg-btn-cancel" gaevent="'+ conf.cancelGE +'" data-event="cancel" type="button">'+(!conf.cancelText ? '取消' : conf.cancelText)+'</button>';
        conf.content = html;
        var _this = this;
        conf.closeFun = function () {
//            _this._el.animate({
//                translateY: "100%"
//            }, 200, "ease-in");
            _this._el.fadeOut(200);
            _this._el_bg.fadeOut(200);
            closeTimer = setTimeout(function(){
                _this._el.remove();
                _this._el_bg.remove();
            }, 300);
        }
        this._show(conf);
    },
    slide: function (dom, conf) {
        conf.type = 'slide';
        conf.dom = dom;
        var _this = this;
        conf.closeFun = function () {
//            _this._el.animate({
//                translateY: "100%"
//            }, 200, "ease-in");
            _this._el.fadeOut(200);
            _this._el_bg.fadeOut(200);
            closeTimer = setTimeout(function(){
                _this._el.remove();
                _this._el_bg.remove();
            }, 300);
        }
        this._show(conf);
    },
    /**
     * 自定义弹框
     * @namespace MT.msg
     * @method diy
     * @param {String|Element} html 弹出框显示内容
     * @param {Object} [fun] 弹出框的配置
     *     {
         *         fun : function(){},
         *         ...
         *     }
     * @param {Objcet} opt 配置，类似其他方法的 conf
     *      {
         *          type: 'diy',
         *          closeOut: true
         *      }
     */
    diy : function(html, fun, opt){
        var conf = {
            content: html,
            type: opt.type || 'diy',
            closeOut: (opt.closeOut === false ? false : true)
        };
        this._fun = fun || {};
        this._show(conf);
    }
};

//var s = document.createElement("style");
//s.innerHTML = ".msg-bg{background:rgba(0,0,0,.7);position:absolute;top:0;left:0;width:100%;z-index:998}a.msg-close{position: absolute;right: 10px;font-size: 20px;line-height: 20px;}.msg-doc{position:fixed;width:90%;left:5%;bottom:45%;border-radius:.06rem;background:#fff;overflow:hidden;z-index:999}.msg-hd{background:#f0efed;color:#333;text-align:center;padding:.18rem 0;overflow:hidden;font-size:.36rem;border-bottom:1px solid #DDD8CE}.msg-bd{font-size:.34rem;padding:.43rem;border-bottom:1px solid #D8D8D8}.msg-toast{left:25%;background:rgba(0,0,0,.8);font-size:.35rem;width:50%;color:#fff;border:0;text-align:center;padding:.4rem;-webkit-animation-name:pop-hide;-webkit-animation-duration:5s;border-radius:.12rem;bottom:50%;opacity:0;pointer-events:none}.msg-confirm,.msg-alert,.msg-buttons_dialog{-webkit-animation-name:pop;-webkit-animation-duration:.3s}.msg-option{-webkit-animation-name:slideup;-webkit-animation-duration:.3s}@-webkit-keyframes pop-hide{0%{-webkit-transform:scale(0.8);opacity:0}2%{-webkit-transform:scale(1.1);opacity:1}6%{-webkit-transform:scale(1)}90%{-webkit-transform:scale(1);opacity:1}100%{-webkit-transform:scale(0.9);opacity:0}}@-webkit-keyframes pop{0%{-webkit-transform:scale(0.8);opacity:0}40%{-webkit-transform:scale(1.1);opacity:1}100%{-webkit-transform:scale(1)}}@-webkit-keyframes slideup{0%{-webkit-transform:translateY(100%)}40%{-webkit-transform:translateY(-10%)}100%{-webkit-transform:translateY(0)}}.msg-ft{display:-webkit-box;display:-ms-flexbox;font-size:.34rem}.msg-ft .msg-btn{display:block;-webkit-box-flex:1;-ms-flex:1;margin-right:-1px;border-right:1px solid #D8D8D8;height:.88rem;line-height:.88rem;text-align:center;color:#06c1ae}.msg-btn:last-child{border-right:0}.msg-option{background:0;bottom:.5rem}.msg-option div:first-child,.msg-option .msg-option-btns:first-child .btn:first-child{border-radius:.06rem .06rem 0 0;border-top:0}.msg-option .btn{width:100%;background:#fff;border:0;color:#06c1ae;border-radius:0}.msg-option .msg-bd{background:#fff;border-bottom:0}.msg-option .btn{height:.8rem;line-height:.8rem;border-top:1px solid #ccc}.msg-option-btns .btn:last-child{border-radius:0 0 .06rem .06rem;border-bottom:1px solid #ccc}.msg-option .msg-btn-cancel{padding:0;margin-top:.14rem;color:#06c1ae;border-radius:.06rem}.msg-dialog .msg-hd{background-color:#fff}.msg-dialog .msg-bd{background-color:#f0efed}.msg-slide{background:0;bottom:0;left:0;right:0;border-radius:0;-webkit-animation-name:slideup;-webkit-animation-duration:.3s}";
//document.head.appendChild(s);
